package com.qy.worksheetsystem.controller;

import com.qy.worksheetsystem.model.MessageResult;

import com.qy.worksheetsystem.model.MessageResultV2;
import com.qy.worksheetsystem.service.PersonWorkService;
import com.qy.worksheetsystem.service.WorkCalendarService;
import com.qy.worksheetsystem.util.DateUtil;
import com.qy.worksheetsystem.util.JWTUtil;
import com.qy.worksheetsystem.vo.InsertJobWorkingVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.text.SimpleDateFormat;
import java.util.Date;

@RestController
@RequestMapping("/work/personwork")
@Api(value = "工时填报",tags="工时填报")
public class PersonWorkController {
    @Autowired
    private PersonWorkService personWorkService;

    @ApiOperation(value = "获取可填报日期的已填报小时数", notes = "获取可填报日期的已填报小时数，判断每天填报是否超8小时")
    @RequestMapping(value = "/getAvailableDateInfo", method = RequestMethod.GET)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "token", value = "token", required = true, paramType = "header", dataType = "String"),
            @ApiImplicitParam(name = "beginTime", value = "开始时间yyyy-MM-dd", required = true, paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "endTime", value = "开始时间yyyy-MM-dd", required = true, paramType = "query", dataType = "String"),
    })
    public MessageResult getAvailableDateInfo(@RequestHeader("token") String token, String beginTime,String endTime) {
        String number = JWTUtil.getCacheNumber(token);
        if (StringUtils.isEmpty(number)) {
            return MessageResult.error("token异常");
        }
        int isValid = DateUtil.isValidDate(beginTime, endTime);

        if (isValid== 1) {
            return MessageResultV2.error("请输入正确的日期时间，日期格式例如2022-01-01");
        }else if (isValid== 2){
            return MessageResultV2.error("开始时间不能大于结束时间");
        }
        MessageResultV2 result = MessageResultV2.success();
        result.setData(personWorkService.getAvailableDateInfo(number,beginTime,endTime));
        return result;
    }

    @ApiOperation(value = "报工新增", notes = "报工新增")
    @RequestMapping(value = "/insertWork", method = RequestMethod.POST)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "token", value = "token", required = true, paramType = "header", dataType = "String"),
    })
    public MessageResult insertWork(@RequestHeader("token") String token, @RequestBody InsertJobWorkingVO jobWork) {

        String number = JWTUtil.getCacheNumber(token);
        if (StringUtils.isEmpty(number)) {
            return MessageResult.error("token异常");
        }
        return MessageResult.success().add("jobWork",jobWork);
    }

    @ApiOperation(value = "获取员工报工列表", notes = "获取员工报工列表")
    @RequestMapping(value = "/getPersonWorkList", method = RequestMethod.GET)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "token", value = "token", required = true, paramType = "header", dataType = "String"),
            @ApiImplicitParam(name = "beginTime", value = "开始时间yyyy-MM-dd", required = true, paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "endTime", value = "开始时间yyyy-MM-dd", required = true, paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "state", value = "true已提交，false待提交", required = true, paramType = "query", dataType = "Boolean"),
    })
    public MessageResult getPersonWorkList(@RequestHeader("token") String token, String beginTime,String endTime,Boolean state) {
        String number = JWTUtil.getCacheNumber(token);
        if (StringUtils.isEmpty(number)) {
            return MessageResult.error("token异常");
        }

        return MessageResult.success().add("beginTime",beginTime).add("endTime",endTime).add("state",state);
    }
    @ApiOperation(value = "获取员工汇总信息", notes = "获取员工汇总信息")
    @RequestMapping(value = "/getPersonWorkSumInfo", method = RequestMethod.GET)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "token", value = "token", required = true, paramType = "header", dataType = "String"),
            @ApiImplicitParam(name = "beginTime", value = "开始时间yyyy-MM-dd", required = true, paramType = "query", dataType = "String"),
            @ApiImplicitParam(name = "endTime", value = "开始时间yyyy-MM-dd", required = true, paramType = "query", dataType = "String"),
    })
    public MessageResult getPersonWorkSumInfo(@RequestHeader("token") String token, String beginTime,String endTime,Boolean state) {
        String number = JWTUtil.getCacheNumber(token);
        if (StringUtils.isEmpty(number)) {
            return MessageResult.error("token异常");
        }

        return MessageResult.success().add("beginTime",beginTime).add("endTime",endTime);
    }

}